diff --git a/elementaryx-dev.el b/elementaryx-dev.el
index dd1a48d11acfef710f99e938398b7f4c24b30bb5..f768d21854bdc6aea3b321dab495a4afa287a47a 100644
--- a/elementaryx-dev.el
+++ b/elementaryx-dev.el
@@ -18,7 +18,7 @@
 
   ;; Treesitter config: remap classical mode to ts-mode
   (add-to-list 'major-mode-remap-alist '(bash-mode . bash-ts-mode))
-  (add-to-list 'major-mode-remap-alist '(bibtex-mode . bibtex-ts-mode))
+  ;; (add-to-list 'major-mode-remap-alist '(bibtex-mode . bibtex-ts-mode)) ;; TODO: investigate bug
   (add-to-list 'major-mode-remap-alist '(c-mode . c-ts-mode))
   (add-to-list 'major-mode-remap-alist '(c++-mode . c++-ts-mode))
   (add-to-list 'major-mode-remap-alist
@@ -34,14 +34,14 @@
   (add-to-list 'auto-mode-alist '("CMakeLists\\.txt\\'" . cmake-ts-mode))
   (add-to-list 'auto-mode-alist '("\\.cmake\\'" . cmake-ts-mode))
   (add-to-list 'auto-mode-alist '("\\Dockerfile\\'" . dockerfile-ts-mode))
   ;; (add-to-list 'auto-mode-alist '("\\.hs\\'" . haskell-ts-mode)) ;; TODO: inverstigate bug
   ;; (add-to-list 'auto-mode-alist '("\\.lhs\\'" . haskell-ts-mode)) ;; TODO: inverstigate bug
   ;; (add-to-list 'auto-mode-alist '("\\.jl\\'" . julia-ts-mode)) ;; TODO: inverstigate bug
   (add-to-list 'auto-mode-alist '("\\.json\\'" . json-ts-mode))
-  ;; (add-to-list 'auto-mode-alist '("\\.lua\\'" . lua-ts-mode)) ;; TODO: inverstigate bug
-  (add-to-list 'auto-mode-alist '("\\.md\\'" . markdown-ts-mode)) ;; TODO: inverstigate bug
-  (add-to-list 'auto-mode-alist '("\\.markdown\\'" . markdown-ts-mode)) ;; TODO: inverstigate bug
-  ;; (add-to-list 'auto-mode-alist '("\\.php\\'" . php-ts-mode)) ;; TODO: inverstigate bug
+  ;; (add-to-list 'auto-mode-alist '("\\.lua\\'" . lua-ts-mode)) ;; TODO: investigate bug
+  (add-to-list 'auto-mode-alist '("\\.md\\'" . markdown-ts-mode)) ;; TODO: investigate bug
+  (add-to-list 'auto-mode-alist '("\\.markdown\\'" . markdown-ts-mode)) ;; TODO: investigate bug
+  ;; (add-to-list 'auto-mode-alist '("\\.php\\'" . php-ts-mode)) ;; TODO: investigate bug
   (add-to-list 'auto-mode-alist '("\\.rs\\'" . rust-ts-mode))
   (add-to-list 'auto-mode-alist '("\\.ts\\'" . typescript-ts-mode))
   ;; (add-to-list 'auto-mode-alist '("\\.ml\\'" . ml-ts-mode)) ;; TODO: not sure how to set it up with tree-sitter-ocaml
@@ -34,14 +34,14 @@
   (add-to-list 'auto-mode-alist '("\\.cmake\\'" . cmake-ts-mode))
   (add-to-list 'auto-mode-alist '("\\Dockerfile\\'" . dockerfile-ts-mode))
-  ;; (add-to-list 'auto-mode-alist '("\\.hs\\'" . haskell-ts-mode)) ;; TODO: inverstigate bug
-  ;; (add-to-list 'auto-mode-alist '("\\.lhs\\'" . haskell-ts-mode)) ;; TODO: inverstigate bug
-  ;; (add-to-list 'auto-mode-alist '("\\.jl\\'" . julia-ts-mode)) ;; TODO: inverstigate bug
+  ;; (add-to-list 'auto-mode-alist '("\\.hs\\'" . haskell-ts-mode)) ;; TODO: investigate bug
+  ;; (add-to-list 'auto-mode-alist '("\\.lhs\\'" . haskell-ts-mode)) ;; TODO: investigate bug
+  ;; (add-to-list 'auto-mode-alist '("\\.jl\\'" . julia-ts-mode)) ;; TODO: investigate bug
   (add-to-list 'auto-mode-alist '("\\.json\\'" . json-ts-mode))